@@ -17,7 +17,6 @@
 #
 import os
 import logging
-from tempfile import NamedTemporaryFile
 from typing import (
     Dict, List, Optional, Tuple, Any
 )
@@ -25,6 +24,7 @@ from typing import (
 # project
 import kiwi.defaults as defaults
 
+from kiwi.utils.temporary import Temporary
 from kiwi.defaults import Defaults
 from kiwi.filesystem.base import FileSystemBase
 from kiwi.bootloader.config import BootLoaderConfig
@@ -154,6 +154,9 @@ class DiskBuilder:
         self.result = Result(xml_state)
         self.runtime_config = RuntimeConfig()
 
+        if not self.boot_image.has_initrd_support():
+            log.warning('Building without initrd support !')
+
     def create(self) -> Result:
         """
         Build a bootable disk image and optional installation image
@@ -219,9 +222,10 @@ class DiskBuilder:
         # setup recovery archive, cleanup and create archive if requested
         self.system_setup.create_recovery_archive()
 
-        # prepare boot(initrd) root system
-        log.info('Preparing boot system')
-        self.boot_image.prepare()
+        # prepare initrd
+        if self.boot_image.has_initrd_support():
+            log.info('Preparing boot system')
+            self.boot_image.prepare()
 
         # precalculate needed disk size
         disksize_mbytes = self.disk_setup.get_disksize_mbytes()
@@ -247,6 +251,8 @@ class DiskBuilder:
                         loop_provider.get_device(),
                     'grub_directory_name':
                         Defaults.get_grub_boot_directory_name(self.root_dir),
+                    'crypto_disk':
+                        True if self.luks is not None else False,
                     'boot_is_crypto':
                         self.boot_is_crypto
                 }
@@ -268,18 +274,31 @@ class DiskBuilder:
 
         # create luks on current root device if requested
         luks_root = None
-        if self.luks:
+        if self.luks is not None:
             luks_root = LuksDevice(device_map['root'])
             self.luks_boot_keyname = '/.root.keyfile'
             self.luks_boot_keyfile = ''.join(
                 [self.root_dir, self.luks_boot_keyname]
             )
+            # use LUKS key file for the following conditions:
+            # 1. /boot is encrypted
+            #    In this case grub needs to read from LUKS via the
+            #    cryptodisk module which at the moment always asks
+            #    for the passphrase even when empty. The keyfile
+            #    setup makes sure only one interaction on the grub
+            #    stage is needed
+            # 2. LUKS passphrase is configured as empty string
+            #    In this case the keyfile allows to open the
+            #    LUKS pool without asking
+            #
+            luks_need_keyfile = \
+                True if self.boot_is_crypto or self.luks == '' else False
             luks_root.create_crypto_luks(
                 passphrase=self.luks,
                 os=self.luks_os,
-                keyfile=self.luks_boot_keyfile if self.boot_is_crypto else None
+                keyfile=self.luks_boot_keyfile if luks_need_keyfile else None
             )
-            if self.boot_is_crypto:
+            if luks_need_keyfile:
                 self.luks_boot_keyfile_setup = ''.join(
                     [self.root_dir, '/etc/dracut.conf.d/99-luks-boot.conf']
                 )
@@ -401,8 +420,9 @@ class DiskBuilder:
             if self.disk_resize_requested:
                 self.boot_image.include_module('kiwi-repart')
 
-        # create initrd cpio archive
-        self.boot_image.create_initrd(self.mbrid)
+        # create initrd
+        if self.boot_image.has_initrd_support():
+            self.boot_image.create_initrd(self.mbrid)
 
         # create second stage metadata to system image
         self._copy_first_boot_files_to_system_image()
@@ -443,13 +463,14 @@ class DiskBuilder:
             self.diskname
         )
         # store image file name in result
+        compression = self.runtime_config.get_bundle_compression(default=True)
+        if self.luks != None:
+            compression = False
         self.result.add(
             key='disk_image',
             filename=self.diskname,
             use_for_bundle=True if not self.image_format else False,
-            compress=self.runtime_config.get_bundle_compression(
-                default=True
-            ),
+            compress=compression,
             shasum=True
         )
 
@@ -540,9 +561,8 @@ class DiskBuilder:
         :rtype: instance of :class:`Result`
         """
         if self.install_media:
-            if self.initrd_system == 'dracut':
-                boot_image = None
-            else:
+            boot_image = None
+            if self.initrd_system == 'kiwi':
                 boot_image = self.boot_image
             install_image = InstallImageBuilder(
                 self.xml_state, self.root_dir, self.target_dir,
@@ -723,7 +743,7 @@ class DiskBuilder:
 
         if self.root_filesystem_is_overlay:
             log.info('--> creating readonly root partition')
-            squashed_root_file = NamedTemporaryFile()
+            squashed_root_file = Temporary().new_file()
             squashed_root = FileSystemSquashFs(
                 device_provider=DeviceProvider(), root_dir=self.root_dir,
                 custom_args={
@@ -901,7 +921,7 @@ class DiskBuilder:
             options = ['defaults']
         block_operation = BlockID(device)
         if self.volume_manager_name and self.volume_manager_name == 'lvm' \
-           and mount_point == '/':
+           and (mount_point == '/' or mount_point == 'swap'):
             fstab_entry = ' '.join(
                 [
                     device, mount_point,
@@ -1033,7 +1053,7 @@ class DiskBuilder:
 
         log.info('--> Syncing root filesystem data')
         if self.root_filesystem_is_overlay:
-            squashed_root_file = NamedTemporaryFile()
+            squashed_root_file = Temporary().new_file()
             squashed_root = FileSystemSquashFs(
                 device_provider=DeviceProvider(), root_dir=self.root_dir,
                 custom_args={
@@ -1157,10 +1177,11 @@ class DiskBuilder:
                         self.boot_image.boot_root_directory
                     )
 
-        log.info('--> initrd archive as %s', boot_names.initrd_name)
-        Command.run(
-            [
-                'mv', self.boot_image.initrd_filename,
-                self.root_dir + ''.join(['/boot/', boot_names.initrd_name])
-            ]
-        )
+        if self.boot_image.initrd_filename:
+            log.info('--> initrd archive as %s', boot_names.initrd_name)
+            Command.run(
+                [
+                    'mv', self.boot_image.initrd_filename,
+                    self.root_dir + ''.join(['/boot/', boot_names.initrd_name])
+                ]
+            )
