@@ -15,10 +15,10 @@
 # You should have received a copy of the GNU General Public License
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
-from tempfile import NamedTemporaryFile
 from lxml import etree
 
 # project
+from kiwi.utils.temporary import Temporary
 from kiwi.defaults import Defaults
 from kiwi.exceptions import KiwiConfigFileFormatNotSupported
 
@@ -56,13 +56,17 @@ class MarkupBase:
             parsed_description = etree.parse(description)
         except etree.XMLSyntaxError:
             raise KiwiConfigFileFormatNotSupported(
-                'Support for non-XML formatted config files requires '
-                'the Python anymarkup module.')
+                'Configuration file could not be parsed. '
+                'In case your configuration file is XML it most likely '
+                'contains a syntax error. For other formats the '
+                'Python anymarkup module is required.')
 
         xslt_transform = etree.XSLT(
             etree.parse(Defaults.get_xsl_stylesheet_file())
         )
-        self.description_xslt_processed = NamedTemporaryFile(prefix='xslt-')
+        self.description_xslt_processed = Temporary(
+            prefix='kiwi_xslt-'
+        ).new_file()
         with open(self.description_xslt_processed.name, "wb") as xsltout:
             xsltout.write(
                 etree.tostring(xslt_transform(parsed_description))
