@@ -113,7 +113,8 @@ class PackageManagerZypper(PackageManagerBase):
         """
         command = ['zypper'] + self.zypper_args + [
             '--root', self.root_dir,
-            'install', '--auto-agree-with-licenses'
+            'install', '--download', 'in-advance',
+            '--auto-agree-with-licenses'
         ] + self.custom_args + ['--'] + self._install_items()
         return Command.call(
             command, self.command_env
@@ -144,7 +145,8 @@ class PackageManagerZypper(PackageManagerBase):
                 )
         return Command.call(
             ['chroot', self.root_dir, 'zypper'] + self.chroot_zypper_args + [
-                'install', '--auto-agree-with-licenses'
+                'install', '--download', 'in-advance',
+                '--auto-agree-with-licenses'
             ] + self.custom_args + ['--'] + self._install_items(),
             self.chroot_command_env
         )
@@ -201,7 +203,8 @@ class PackageManagerZypper(PackageManagerBase):
         """
         return Command.call(
             ['chroot', self.root_dir, 'zypper'] + self.chroot_zypper_args + [
-                'update', '--auto-agree-with-licenses'
+                'update', '--download', 'in-advance',
+                '--auto-agree-with-licenses'
             ] + self.custom_args,
             self.chroot_command_env
         )
