@@ -17,10 +17,10 @@
 #
 import os
 from configparser import ConfigParser
-from tempfile import NamedTemporaryFile
 from typing import List, Dict
 
 # project
+from kiwi.utils.temporary import Temporary
 from kiwi.defaults import Defaults
 from kiwi.command import Command
 from kiwi.repository.base import RepositoryBase
@@ -108,15 +108,16 @@ class RepositoryZypper(RepositoryBase):
             )
         }
 
-        self.runtime_zypper_config_file = NamedTemporaryFile(
+        self.runtime_zypper_config_file = Temporary(
             dir=self.root_dir
-        )
-        self.runtime_zypp_config_file = NamedTemporaryFile(
+        ).new_file()
+        self.runtime_zypp_config_file = Temporary(
             dir=self.root_dir
-        )
+        ).new_file()
 
         self.zypper_args = [
             '--non-interactive',
+            '--gpg-auto-import-keys',
             '--pkg-cache-dir', self.shared_zypper_dir['pkg-cache-dir'],
             '--reposd-dir', self.shared_zypper_dir['reposd-dir'],
             '--solv-cache-dir', self.shared_zypper_dir['solv-cache-dir'],
@@ -246,7 +247,8 @@ class RepositoryZypper(RepositoryBase):
         prio: int = None, dist: str = None, components: str = None,
         user: str = None, secret: str = None, credentials_file: str = None,
         repo_gpgcheck: bool = False, pkg_gpgcheck: bool = False,
-        sourcetype: str = None, use_for_bootstrap: bool = False
+        sourcetype: str = None, use_for_bootstrap: bool = False,
+        customization_script: str = None
     ) -> None:
         """
         Add zypper repository
@@ -264,6 +266,8 @@ class RepositoryZypper(RepositoryBase):
         :param bool pkg_gpgcheck: enable package signature validation
         :param str sourcetype: unused
         :param boot use_for_bootstrap: unused
+        :param str customization_script:
+            custom script called after the repo file was created
         """
         if credentials_file:
             repo_secret = os.sep.join(
@@ -330,6 +334,8 @@ class RepositoryZypper(RepositoryBase):
             )
         with open(repo_file, 'w') as repo:
             repo_config.write(repo)
+        if customization_script:
+            self.run_repo_customize(customization_script, repo_file)
         self._restore_package_cache()
 
     def import_trusted_keys(self, signing_keys: List) -> None:
