@@ -34,11 +34,11 @@ class TestDiskFormatQcow2:
         assert self.disk_format.options == ['-o', 'option=value']
 
     @patch('kiwi.storage.subformat.qcow2.Command.run')
-    @patch('kiwi.storage.subformat.qcow2.NamedTemporaryFile')
-    def test_create_image_format(self, mock_NamedTemporaryFile, mock_command):
+    @patch('kiwi.storage.subformat.qcow2.Temporary.new_file')
+    def test_create_image_format(self, mock_Temporary_new_file, mock_command):
         tmpfile = Mock()
         tmpfile.name = 'tmpfile'
-        mock_NamedTemporaryFile.return_value = tmpfile
+        mock_Temporary_new_file.return_value = tmpfile
         self.disk_format.create_image_format()
         assert mock_command.call_args_list == [
             call(
